@@ -29,7 +29,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.0.9";
+our $VERSION = "5.1.0";
 
 
 =head2 on_insert
@@ -76,7 +76,13 @@ EOF
             exit(1);
         }
 
-        $data->{ 'body' } = Text::Markdown::markdown( $data->{ 'body' } );
+        foreach my $key (qw! truncatedbody body !)
+        {
+            $data->{ $key } = Text::Markdown::markdown( $data->{ $key } )
+              if ( $data->{ $key } );
+        }
+
+
 
     }
     return ($data);
