@@ -29,7 +29,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.0.9";
+our $VERSION = "5.1.0";
 
 
 =head2 on_insert
@@ -75,8 +75,11 @@ If you're on a Debian GNU/Linux system you can fix this via:
 EOF
             exit(1);
         }
-
-        $data->{ 'body' } = Text::MultiMarkdown::markdown( $data->{ 'body' } );
+        foreach my $key (qw! truncatedbody body !)
+        {
+            $data->{ $key } = Text::MultiMarkdown::markdown( $data->{ $key } )
+              if ( $data->{ $key } );
+        }
 
     }
     return ($data);
