@@ -41,7 +41,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.0.9";
+our $VERSION = "5.1.0";
 
 
 =head2 on_initiate
@@ -77,13 +77,18 @@ sub on_initiate
 
     my $tags;
 
+    # Default sizing options
+    my $min  = $config->{ 'tag_cloud_size_min' }  || 5;
+    my $max  = $config->{ 'tag_cloud_size_max' }  || 60;
+    my $step = $config->{ 'tag_cloud_size_step' } || 5;
+
     #
     # Process the results.
     #
     while ( $sql->fetch() )
     {
-        my $size = $count * 5 + 5;
-        if ( $size > 60 ) {$size = 60;}
+        my $size = $count * $step + $min;
+        $size = $max if ( $size > $max );
 
         push( @$tags,
               {  tag   => $tag,
