@@ -30,7 +30,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.0.9";
+our $VERSION = "5.1.0";
 
 
 =head2 on_insert
@@ -80,7 +80,15 @@ EOF
         }
 
         my $textile = new Text::Textile;
-        $data->{ 'body' } = $textile->process( $data->{ 'body' } );
+
+        foreach my $key (qw! truncatedbody body !)
+        {
+            $data->{ $key } = $textile->process( $data->{ $key } )
+              if ( $data->{ $key } );
+        }
+
+
+
     }
 
     return ($data);
